=======
History
=======

0.2.1 (2018-03-19)
------------------

* Increase test coverage for comparison operators
* Fix parse error when given a list of lists domain
* Quote (') string values in string parser (for SQL clauses)

0.2.0 (2018-03-03)
------------------

* API creation.
* Parse domain list to string.
* Parse domain list to expression.

0.1.0 (2018-02-18)
------------------

* First release on PyPI.
